@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-12-02 18:33:51
+@LastEditTime: 2021-12-15 10:39:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -198,18 +198,10 @@ class GetUnbindApplyHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
-        reason = self.get_param("reason", "误封号,申请解封")
-
-        invoke_result_data = InvokeResultData()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.get_black_info_dict(app_id, act_id, user_id)
-        if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        else:
-            return self.response_json_success()
+        return self.response_json_success(user_base_model.get_black_info_dict(app_id, act_id, user_id))
 
 
 class GetCouponPrizeHandler(ClientBaseHandler):
