@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-12-02 17:57:41
+@LastEditTime: 2021-12-07 15:26:38
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -10,7 +10,6 @@ from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.db_models.asset.asset_log_model import *
 from seven_cloudapp_frame.models.db_models.asset.asset_only_model import *
 from seven_cloudapp_frame.models.db_models.user.user_asset_model import *
-from seven_cloudapp_frame.models.db_models.asset.asset_inventory_model import *
 from seven_cloudapp_frame.models.db_models.asset.asset_warn_notice_model import *
 from seven_cloudapp_frame.models.seven_model import *
 
@@ -147,7 +146,6 @@ class AssetBaseModel():
         user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
         asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
         asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
-        asset_inventory_model = AssetInventoryModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
 
         acquire_lock_name = f"userasset:{user_asset_id_md5}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
@@ -171,6 +169,12 @@ class AssetBaseModel():
                     invoke_result_data.error_code = "no_enough"
                     invoke_result_data.error_message = "变更后的资产不能为负数"
                     return invoke_result_data
+                if user_asset.asset_value + asset_value > 2147483647:
+                    SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "no_enough"
+                    invoke_result_data.error_message = "变更后的资产不能大于整形的最大值"
+                    return invoke_result_data
 
                 old_user_asset_id = user_asset.id
                 history_asset_value = user_asset.asset_value
@@ -196,35 +200,6 @@ class AssetBaseModel():
             user_asset.asset_check_code = self.get_asset_check_code(user_asset_id_md5, user_asset.asset_value, app_id)
             user_asset.modify_date = now_datetime
 
-            old_asset_inventory_id = 0
-            asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
-            asset_inventory = asset_inventory_model.get_cache_entity("id_md5=%s",params=[asset_inventory_id_md5])
-            asset_inventory_update_sql = f"process_count=0,now_value={user_asset.asset_value}"
-            if asset_inventory:
-                old_asset_inventory_id = asset_inventory.id
-                if asset_value > 0:
-                    asset_inventory_update_sql += f",inc_value=inc_value+{asset_value}"
-                else:
-                    asset_inventory_update_sql += f",dec_value=dec_value+{asset_value}"
-            else:
-                asset_inventory = AssetInventory()
-                asset_inventory.id_md5 = asset_inventory_id_md5
-                asset_inventory.app_id = app_id
-                asset_inventory.act_id = act_id
-                asset_inventory.user_id = user_id
-                asset_inventory.open_id = open_id
-                asset_inventory.user_nick = user_nick
-                asset_inventory.asset_type = asset_type
-                asset_inventory.asset_object_id = asset_object_id
-                if asset_value > 0:
-                    asset_inventory.inc_value += asset_value
-                else:
-                    asset_inventory.dec_value += asset_value
-                asset_inventory.history_value = history_asset_value
-                asset_inventory.now_value = user_asset.asset_value
-                asset_inventory.create_date = now_datetime
-                asset_inventory.create_day = now_day_int
-
             asset_log = AssetLog()
             asset_log.app_id = app_id
             asset_log.act_id = act_id
@@ -265,13 +240,8 @@ class AssetBaseModel():
                 user_asset_model.update_entity(user_asset, "asset_value,asset_check_code,modify_date")
             else:
                 user_asset_model.add_entity(user_asset)
-            if old_asset_inventory_id != 0:
-                asset_inventory_model.update_table(asset_inventory_update_sql, "id=%s", params=[old_asset_inventory_id])
-            else:
-                asset_inventory_model.add_entity(asset_inventory)
             if only_id:
                 asset_only_model.add_entity(asset_only)
-
             asset_log_model.add_entity(asset_log)
 
             result = db_transaction.commit_transaction()
@@ -289,6 +259,22 @@ class AssetBaseModel():
                 redis_init.hset(only_cache_key, only_id, 1)
                 redis_init.expire(only_cache_key, 24 * 3600)
             self._delete_asset_dependency_key(act_id,user_id)
+
+            asset_queue = {}
+            asset_queue["app_id"] = app_id
+            asset_queue["act_id"] = act_id
+            asset_queue["open_id"] = open_id
+            asset_queue["user_nick"] = user_nick
+            asset_queue["user_id"] = user_id
+            asset_queue["asset_type"] = asset_type
+            asset_queue["asset_object_id"] = asset_object_id
+            asset_queue["now_value"] = user_asset.asset_value
+            asset_queue["operate_value"] = asset_value
+            asset_queue["history_asset_value"] = history_asset_value
+            asset_queue["now_day_int"] = now_day_int
+            asset_queue["create_date"] = now_datetime
+            redis_init.rpush(f"asset_queue_list:{str(user_id % 10)}",SevenHelper.json_dumps(asset_queue))
+
             invoke_result_data.data = {"user_asset":user_asset.__dict__}
 
         except Exception as ex:
