@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-12-06 17:09:04
+@LastEditTime: 2021-12-15 17:06:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,7 +19,7 @@ class AssetConsoleModel():
     """
     :description: 资产控制台业务模型
     """
-    def console_asset_warn(self, mod_count=10):
+    def console_asset_warn(self, mod_count=1):
         """
         :description: 控制台资产预警
         :param mod_count: 单表队列数
@@ -34,11 +34,13 @@ class AssetConsoleModel():
                 self._start_process_user_asset_warn(str(i), mod_count)
 
         for i in range(mod_count):
-            n = threading.Thread(target=self._process_asset_inventory_queue, args=[i])
-            n.start()
             j = threading.Thread(target=self._process_asset_inventory_warn, args=[i, mod_count])
             j.start()
 
+        for i in range(10):
+            n = threading.Thread(target=self._process_asset_inventory_queue, args=[i])
+            n.start()
+
         l = threading.Thread(target=self._process_onlyid_warn, args=[])
         l.start()
 
@@ -67,7 +69,10 @@ class AssetConsoleModel():
             try:
                 now_date = TimeHelper.get_now_format_time()
                 now_day_int = SevenHelper.get_now_day_int()
-                asset_log_list = asset_log_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
+                if mod_count == 1:
+                    asset_log_list = asset_log_model.get_list(f"now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
+                else:
+                    asset_log_list = asset_log_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
                 if len(asset_log_list) > 0:
                     for asset_log in asset_log_list:
                         try:
@@ -210,7 +215,10 @@ class AssetConsoleModel():
             try:
                 now_date = TimeHelper.get_now_format_time()
                 now_day_int = SevenHelper.get_now_day_int()
-                asset_inventory_list = asset_inventory_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
+                if mod_count == 1:
+                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
+                else:
+                    asset_inventory_list = asset_inventory_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
                 if len(asset_inventory_list) > 0:
                     for asset_inventory in asset_inventory_list:
                         try:
