@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-09-17 20:05:33
+@LastEditTime: 2021-12-17 10:32:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -56,6 +56,7 @@ class IpBaseModel():
             return invoke_result_data
 
         ip_info = None
+        old_ip_info = None
         is_add = False
         ip_info_model = IpInfoModel(context=self)
         if ip_id > 0:
@@ -71,8 +72,8 @@ class IpBaseModel():
             ip_info = IpInfo()
         ip_info.app_id = app_id
         ip_info.act_id = act_id
-        ip_info.series_name = ip_name
-        ip_info.series_pic = ip_pic
+        ip_info.ip_name = ip_name
+        ip_info.ip_pic = ip_pic
         ip_info.show_pic = show_pic
         ip_info.sort_index = sort_index
         ip_info.is_release = is_release
