@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-02 15:41:38
+@LastEditTime: 2021-12-16 19:22:39
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -16,8 +16,10 @@ class TopBaseModel():
     """
     :description: 淘宝top接口业务模型
     """
-    def __init__(self,context):
+    def __init__(self,context,logging_error=None,logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def instantiate(self,app_id,user_nick,access_token,app_key, app_secret,is_log=False):
         """
@@ -107,7 +109,11 @@ class TopBaseModel():
             req.template_version = template_version
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序实例化】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序实例化】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序实例化】")
+
             #录入数据库
             result_app = resp["miniapp_template_instantiate_response"]
             app_info = AppInfo()
@@ -151,7 +157,10 @@ class TopBaseModel():
             invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token}
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             if "submsg" in str(ex):
                 content_list = str(ex).split()
                 for content in content_list:
@@ -185,7 +194,10 @@ class TopBaseModel():
             req.template_version = client_ver
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app更新】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app更新】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app更新】")
             if resp and ("miniapp_template_updateapp_response" in resp.keys()):
                 app_version = resp["miniapp_template_updateapp_response"]["app_version"]
                 invoke_result_data = self.online_app(app_id, client_template_id, client_ver, app_version, access_token, is_log)
@@ -197,7 +209,10 @@ class TopBaseModel():
                     AppInfoModel(context=self.context).update_entity(app_info, "app_ver,template_ver,modify_date")
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -232,7 +247,10 @@ class TopBaseModel():
             req.num_iids = num_iids
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取sku名称】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取sku名称】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取sku名称】")
             if "items_seller_list_get_response" in resp.keys():
                 if "items" in resp["items_seller_list_get_response"].keys():
                     props_names = resp["items_seller_list_get_response"]["items"]["item"][0]["props_name"].split(';')
@@ -246,7 +264,10 @@ class TopBaseModel():
                             return invoke_result_data
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -281,14 +302,20 @@ class TopBaseModel():
             req.tid = order_no
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单笔订单】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单笔订单】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单笔订单】")
             if "open_trade_get_response" in resp.keys():
                 if "trade" in resp["open_trade_get_response"]:
                     invoke_result_data.data = resp["open_trade_get_response"]["trade"]
                     return invoke_result_data
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -303,7 +330,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step"):
+    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step",field="tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"):
         """
         :description: 获取淘宝购买订单
         :param open_id：open_id
@@ -315,6 +342,7 @@ class TopBaseModel():
         :param page_size：页大小
         :param is_log：是否记录返回信息
         :param type：订单类型
+        :param field：返回字段
         :return InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -324,7 +352,7 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.OpenTradesSoldGetRequest()
-            req.fields = "tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"
+            req.fields = field
             req.type = type
             req.buyer_open_id = open_id
             req.page_size = page_size
@@ -341,7 +369,10 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取购买订单】")
+                    if self.context:
+                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取购买订单】")
+                    elif self.logging_link_info:
+                        self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取购买订单】")
                 if "open_trades_sold_get_response" in resp.keys():
                     if "trades" in resp["open_trades_sold_get_response"].keys():
                         all_order = all_order + resp["open_trades_sold_get_response"]["trades"]["trade"]
@@ -350,7 +381,10 @@ class TopBaseModel():
             invoke_result_data.data = all_order
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.data = []
             if "submsg" in str(ex):
@@ -404,7 +438,10 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取退单订单】")
+                    if self.context:
+                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取退单订单】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取退单订单】")
                 if "refunds_receive_get_response" in resp.keys():
                     if "refunds" in resp["refunds_receive_get_response"].keys():
                         all_order = all_order + resp["refunds_receive_get_response"]["refunds"]["refund"]
@@ -413,7 +450,10 @@ class TopBaseModel():
             invoke_result_data.data = all_order
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.data = []
             if "submsg" in str(ex):
@@ -455,11 +495,17 @@ class TopBaseModel():
             req.app_version = app_version
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app上线】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app上线】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【app上线】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -491,11 +537,17 @@ class TopBaseModel():
             req.fields = "sid,title,pic_path"
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取店铺信息】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取店铺信息】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取店铺信息】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -527,11 +579,17 @@ class TopBaseModel():
             req.fields = "user_id,nick,sex"
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -565,14 +623,20 @@ class TopBaseModel():
             req.nick = user_nick
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取订购过期时间】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取订购过期时间】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取订购过期时间】")
             if "article_user_subscribe" not in resp["vas_subscribe_get_response"]["article_user_subscribes"].keys():
                 invoke_result_data.data = "expire"
                 return invoke_result_data
             invoke_result_data.data = resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -594,7 +658,7 @@ class TopBaseModel():
         :param access_token：access_token
         :param app_key:app_key
         :param app_secret:app_secret
-        :param fields：返回字段
+        :param field：返回字段
         :param is_log：是否记录返回信息
         :return InvokeResultData
         :last_editors: HuangJianYi
@@ -613,14 +677,20 @@ class TopBaseModel():
                 req.num_iids = cur_num_iids
                 resp = req.getResponse(access_token)
                 if is_log:
-                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】")
+                    if self.context:
+                        self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】")
+                    elif self.logging_link_info:
+                        self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】")
 
                 if "items_seller_list_get_response" in resp.keys():
                     if "items" in resp["items_seller_list_get_response"].keys():
                         if "item" in resp["items_seller_list_get_response"]["items"].keys():
                             goods_list.extend(resp["items_seller_list_get_response"]["items"]["item"])
             except Exception as ex:
-                self.context.logging_link_error(traceback.format_exc())
+                if self.context:
+                    self.context.logging_link_error(traceback.format_exc())
+                elif self.logging_link_error:
+                    self.logging_link_error(traceback.format_exc())
                 invoke_result_data.success = False
                 if "submsg" in str(ex):
                     content_list = str(ex).split()
@@ -671,14 +741,20 @@ class TopBaseModel():
                 req.order_by = order_tag + ":" + order_by
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】")
             if resp:
                 resp["pageSize"] = page_size
                 resp["pageIndex"] = page_index
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -714,11 +790,17 @@ class TopBaseModel():
             req.num_iid = num_iid
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -766,11 +848,17 @@ class TopBaseModel():
                 resp["pageSize"] = page_size
                 resp["pageIndex"] = page_index
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -808,11 +896,17 @@ class TopBaseModel():
             req.add_bind = status
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序投放商品】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序投放商品】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【小程序投放商品】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -847,11 +941,17 @@ class TopBaseModel():
             req.award_type = "1"
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -889,11 +989,17 @@ class TopBaseModel():
             req.app_name = "promotioncenter-" + config.get_value("server_template_id")
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【发放优惠劵】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【发放优惠劵】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【发放优惠劵】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -924,11 +1030,17 @@ class TopBaseModel():
             req = top.api.CrmMemberIdentityGetRequest()
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -982,7 +1094,10 @@ class TopBaseModel():
             req.extra_info = "{\"source\":\"isvapp\",\"activityId\":\"\",\"entrance\":\"hudong\"}"
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】")
             if "crm_member_joinurl_get_response" in resp.keys():
                 if "result" in resp["crm_member_joinurl_get_response"].keys():
                     if "result" in resp["crm_member_joinurl_get_response"]["result"].keys():
@@ -991,7 +1106,10 @@ class TopBaseModel():
                             invoke_result_data.data = "https:" + invoke_result_data.data
                         return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -1025,11 +1143,17 @@ class TopBaseModel():
             req.miniapp_id = app_id
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单查询】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单查询】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单查询】")
             invoke_result_data.data = resp
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -1068,7 +1192,10 @@ class TopBaseModel():
             req.limit_num = 1
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】")
             if resp and resp["opentrade_special_users_mark_response"]["result"] == 1:
                 #  ------------ TopOpentradeSpecialUserMark: {'opentrade_special_users_mark_response': {'result': 1, 'request_id': 'rsk23xhlk310'}}
                 invoke_result_data.data = True
@@ -1077,7 +1204,10 @@ class TopBaseModel():
             return invoke_result_data
 
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
@@ -1113,7 +1243,10 @@ class TopBaseModel():
             req.item_ids = str(goods_id)
             resp = req.getResponse(access_token)
             if is_log:
-                self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】")
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】")
             # {'opentrade_special_items_bind_response': {'results': {'item_bind_result': [{'bind_ok': False, 'error_message': '商品已绑定到小程序:情之缘1993_好货跳一跳_[3000000029278805]', 'item_id': 632007280726}]}, 'request_id': 'zrq8mt8d8xdo'}}
             if resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]:
                 if not resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]["bind_ok"]:
@@ -1122,7 +1255,10 @@ class TopBaseModel():
                     invoke_result_data.error_message = resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]["error_message"]
             return invoke_result_data
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             invoke_result_data.success = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
