@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-12-03 11:01:25
+@LastEditTime: 2021-12-16 16:27:51
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -216,15 +216,16 @@ class UserBaseModel(FrameBaseModel):
                 user_account.open_id = open_id
                 user_account.user_nick = user_nick
                 user_account.avatar = avatar
-                user_account.is_auth = 0
+                user_account.is_auth = 0 if not user_nick else 1
                 user_account.user_state = 0
                 user_account.create_date = now_datetime
                 user_account.modify_date = now_datetime
                 user_account.id = user_account_model.add_entity(user_account)
             else:
                 user_account.user_nick = user_nick if user_nick and user_account.user_nick != user_nick else user_account.user_nick
+                user_account.is_auth = 0 if not user_account.user_nick else 1
                 user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
-                user_account_model.update_entity(user_account, "user_nick,avatar")
+                user_account_model.update_entity(user_account, "user_nick,avatar,is_auth")
                 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
@@ -239,6 +240,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.avatar = user_account.avatar
                 user_info.user_nick = user_nick if user_nick else user_info.user_nick
                 user_info.avatar = avatar if avatar else user_info.avatar
+                user_info.is_auth = 0 if not user_info.user_nick else 1
                 user_info.create_date = now_datetime
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
@@ -251,12 +253,13 @@ class UserBaseModel(FrameBaseModel):
                     return invoke_result_data
                 user_info.user_nick = user_account.user_nick
                 user_info.avatar = user_account.avatar
+                user_info.is_auth = 0 if not user_info.user_nick else 1
                 # if TimeHelper.difference_minutes(now_datetime,user_info.create_date) > 1:
                 #     user_info.is_new = 0
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
-                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar")
+                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar,is_auth")
                 
                 self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
                     
